import React from 'react';
import { DefaultProps } from '../theme';
declare type ValueType = string | number;
export interface InputNumberProps extends DefaultProps {
    /** value will show as string */
    stringMode?: boolean;
    /** Default value for uncontrolled variant only */
    defaultValue?: ValueType;
    /** Input value for controlled variant */
    value?: ValueType;
    /** width of input */
    width?: number;
    /** Minimal possible value */
    min?: ValueType;
    /** Maximum possible value */
    max?: ValueType;
    /** The step used to increment or decrement the value */
    step?: ValueType;
    /** Whether to show +- controls */
    controls?: boolean;
    /** Parse display value to validate number */
    parser?: (displayValue: string | undefined) => ValueType;
    /** Transform `value` to display value show in input */
    formatter?: (value: ValueType | undefined, info: {
        userTyping: boolean;
        input: string;
    }) => string;
    /** Syntactic sugar of `formatter`. Config precision of display. */
    precision?: number;
    /** Syntactic sugar of `formatter`. Config decimal separator of display. */
    decimalSeparator?: string;
    /** The callback triggered when the value is changed */
    onChange?: (value: ValueType) => void;
    /** The callback function that is triggered when Enter key is pressed */
    onPressEnter?: React.KeyboardEventHandler<HTMLInputElement>;
    /** The callback function that is triggered when click up or down buttons */
    onStep?: (value: ValueType, info: {
        offset: ValueType;
        type: 'up' | 'down';
    }) => void;
}
export declare const InputNumber: import("../utils/types").ComponentWithAs<"input", InputNumberProps>;
export {};
//# sourceMappingURL=InputNumber.d.ts.map