import React, { RefObject } from 'react';
import { ButtonProps } from '../Button/Button';
declare type getContainerFunc = () => HTMLElement;
export interface ModalProps {
    /** Mounts modal if true */
    visible?: boolean;
    /** Whether to apply loading visual effect for OK button or not */
    confirmLoading?: boolean;
    /** Modal title, displayed in header before close button */
    title?: React.ReactNode;
    /** Modal description */
    description?: React.ReactNode;
    /** Modal Icon */
    titleIcon?: React.ReactNode;
    /** Show or hide close button, modal still can be closed with escape key and by clicking outside */
    closable?: boolean;
    /** Specify a function that will be called when a user clicks the OK button */
    onOk?: (e: React.MouseEvent<HTMLElement>) => void;
    /** Specify a function that will be called when a user clicks mask, close button on top right or Cancel button */
    onCancel?: (e: React.MouseEvent<HTMLElement>) => void;
    /** Specify a function that will be called when modal is closed completely */
    afterClose?: () => void;
    /** Centered Modal */
    centered?: boolean;
    /** Width of the modal dialog */
    width?: string | number;
    /** Custom header content */
    header?: React.ReactNode;
    /** Custom header extra content */
    headerExtra?: React.ReactNode;
    /** Custom footer content */
    footer?: React.ReactNode;
    /** 确认按钮文字 */
    okText?: React.ReactNode;
    /** 取消按钮文字 */
    cancelText?: React.ReactNode;
    /** Whether to close the modal dialog when the mask (area outside the modal) is clicked */
    maskClosable?: boolean;
    /** Force render Modal */
    forceRender?: boolean;
    /** Props of the ok button */
    okButtonProps?: ButtonProps;
    /** Props of the cancel button */
    cancelButtonProps?: ButtonProps;
    /** Whether to unmount child components on onClose */
    destroyOnClose?: boolean;
    style?: React.CSSProperties;
    wrapClassName?: string;
    maskTransitionName?: string;
    transitionName?: string;
    className?: string;
    getContainer?: string | HTMLElement | getContainerFunc | false;
    /** Modal z-index property */
    zIndex?: number;
    bodyStyle?: React.CSSProperties;
    /** Style for modal's mask element */
    maskStyle?: React.CSSProperties;
    /** Whether show mask or not */
    mask?: boolean;
    /** Whether support press esc to close */
    keyboard?: boolean;
    wrapProps?: any;
    closeIcon?: React.ReactNode;
    modalRender?: (node: React.ReactNode) => React.ReactNode;
    focusTriggerAfterClose?: boolean;
}
interface ModalRef {
    close?: () => void;
}
export declare type ModalType = 'info' | 'success' | 'error' | 'warn' | 'warning' | 'confirm' | 'open';
export interface ModalFuncProps extends Omit<ModalProps, 'forceRender' | 'destroyOnClose'> {
    content?: React.ReactNode;
    icon?: React.ReactNode;
    type?: ModalType;
    autoFocusButton?: null | 'ok' | 'cancel';
    okCancel?: boolean;
    id?: string;
    ref?: RefObject<ModalRef>;
    onAsyncOk?: () => Promise<any>;
}
export declare const Modal: import("../utils/types").ComponentWithAs<any, ModalProps>;
export {};
//# sourceMappingURL=Modal.d.ts.map