import React from 'react';
import { KubedNumberSize, KubedSizes } from '../theme';
export interface NavItem {
    value: string;
    label: React.ReactNode;
}
export interface NavProps extends Omit<React.ComponentPropsWithoutRef<'div'>, 'value' | 'onChange'> {
    /** Data based on which controls are rendered */
    data: NavItem[];
    /** Current selected value */
    variant?: 'pills' | 'line';
    /** Current selected value */
    value?: string;
    /** Default value for uncontrolled component */
    defaultValue?: string;
    /** Called when value changes */
    onChange?(value: string): void;
    /** Name of the radio group, default to random id */
    name?: string;
    /** True if component should have 100% width */
    fullWidth?: boolean;
    /** Active control color from theme, defaults to white in light color scheme and theme.colors.dark[9] in dark */
    color?: string | 'default' | 'primary' | 'secondary' | 'success' | 'warning' | 'error';
    /** Controls font-size, paddings and height */
    size?: KubedSizes;
    /** Border-radius from theme or number to set border-radius in px */
    radius?: KubedNumberSize;
    /** Transition duration in ms, set to 0 to turn off transitions */
    transitionDuration?: number;
    /** Transition timing function for all transitions, defaults to theme.transitionTimingFunction */
    transitionTimingFunction?: string;
}
export declare function Navs({ data, name, variant, value, onChange, color, fullWidth, radius, size, transitionDuration, transitionTimingFunction, defaultValue, ...others }: NavProps): React.JSX.Element;
export declare namespace Navs {
    var displayName: string;
}
//# sourceMappingURL=Navs.d.ts.map