import React from 'react';
import { DefaultProps, KubedNumberSize } from '../../theme/index';
declare type Value = [number, number];
export interface RangeSliderProps extends DefaultProps, Omit<React.ComponentPropsWithoutRef<'div'>, 'value' | 'onChange' | 'defaultValue'> {
    /** Track border-radius from theme or number to set border-radius in px */
    radius?: KubedNumberSize;
    /** Predefined track and thumb size, number to set sizes in px */
    size?: KubedNumberSize;
    /** Minimal possible value */
    min?: number;
    /** Maximum possible value */
    max?: number;
    /** keep decimals **/
    decimals?: number;
    /** Minimal range interval */
    minRange?: number;
    /** Disable RangeSlider */
    disabled?: boolean;
    /** Number by which value will be incremented/decremented with thumb drag and arrows */
    step?: number;
    /** Current value for controlled slider */
    value?: Value;
    /** Default value for uncontrolled slider */
    defaultValue?: Value;
    /** Called each time value changes */
    onChange?(value: Value): void;
    /** Hidden input name, use with uncontrolled variant */
    name?: string;
    /** Marks which will be placed on the track */
    marks?: {
        value: number;
        label?: React.ReactNode;
        weight?: number;
    }[];
    /** Function to generate label or any react node to render instead, set to null to disable label */
    label?: React.ReactNode | ((value: number) => React.ReactNode);
    /** Label appear/disappear transition */
    labelTransition?: string;
    /** Label appear/disappear transition duration in ms */
    labelTransitionDuration?: number;
    /** Label appear/disappear transition timing function, defaults to theme.transitionRimingFunction */
    labelTransitionTimingFunction?: string;
    /** If true label will be not be hidden when user stops dragging */
    labelAlwaysOn?: boolean;
    /** First thumb aria-label */
    thumbFromLabel?: string;
    /** Second thumb aria-label */
    thumbToLabel?: string;
    /**If true slider label will appear on hover */
    showLabelOnHover?: boolean;
    /** Thumbs children, can be used to add icons */
    thumbChildren?: React.ReactNode;
}
export declare const RangeSlider: React.ForwardRefExoticComponent<RangeSliderProps & React.RefAttributes<HTMLDivElement>>;
export {};
//# sourceMappingURL=RangeSlider.d.ts.map