import type { Header, Row, RowData, Table, TableState } from '@tanstack/react-table';
import * as React from 'react';
import * as BaseTable from '../BaseTable';
import { DataTableRootProps, DefaultOptionsResolved, FeaturesHandlersOptions, StateHandler, StorageStateOptions } from './interfaces';
declare module '@tanstack/react-table' {
    interface TableOptionsResolved<TData extends RowData> extends StorageStateOptions, FeaturesHandlersOptions {
        loading?: boolean;
        autoResetFiltersWhenPageChange?: boolean;
    }
    interface ColumnMeta<TData extends RowData, TValue = unknown> {
        description?: Record<string, any>;
        selectType?: 'single' | 'multiple';
        sortable?: boolean;
        searchKey?: string;
        th?: Omit<BaseTable.TableCellProps, 'ref'>;
        td?: Omit<BaseTable.TableCellProps, 'ref'>;
    }
    interface TableOptions<TData extends RowData> {
        onParamsChange?: (params: Partial<TableState>, key: keyof TableState) => void;
        loading?: boolean;
    }
    interface TableFeature<TData extends RowData = any> extends DefaultOptionsResolved<TData> {
    }
    interface TableMeta<TData extends RowData> {
        tableName: string;
        refetch?: () => void;
        storageStateKeys?: (keyof TableState)[] | '*';
        _defaultConfig?: {
            selectColumnId?: string;
        };
        manual?: boolean;
        enable?: {
            pagination?: boolean;
            toolbar?: boolean;
            visible?: boolean;
            filters?: boolean;
        };
        enableDefault?: {
            toolbar?: boolean;
            th?: boolean;
            td?: boolean;
            tr?: boolean;
        };
        getProps?: {
            filters?: (table: Table<TData>) => BaseTable.ToolbarProps['filterProps'];
            toolbar?: (table: Table<TData>) => Partial<Omit<BaseTable.ToolbarProps, 'filtersProps' | 'enableFilters'>>;
            table?: (table: Table<TData>) => Partial<BaseTable.TableProps>;
            th?: (table: Table<TData>, header: Header<TData, unknown>) => Omit<BaseTable.TableCellProps, 'ref'>;
            pagination?: (table: Table<TData>) => Partial<BaseTable.BaseTablePaginationProps> & {
                total?: number;
            };
            tr?: (table: Table<TData>, row: Row<TData>) => Partial<BaseTable.TableRowProps>;
            td?: (table: Table<TData>, props: Record<string, any>) => Omit<BaseTable.TableCellProps, 'ref'>;
            empty?: () => Partial<BaseTable.TableFilteredEmptyProps>;
        };
        registerHandlers?: StateHandler[];
    }
}
export declare function DataTable<T>({ className, table }: DataTableRootProps<T>): React.JSX.Element;
//# sourceMappingURL=Table.d.ts.map