import React from 'react';
import { KubedNumberSize, KubedSizes } from '../theme';
import { GroupPosition } from '../Group/Group';
import { Tab, TabProps } from './Tab/Tab';
export { Tab };
export type { TabProps };
export interface TabsProps extends Omit<React.ComponentPropsWithoutRef<'div'>, 'value' | 'onChange'> {
    /** Current selected value */
    variant?: 'pills' | 'line' | 'outline';
    /** Current selected value */
    activeKey?: string;
    /** Default value for uncontrolled component */
    defaultActiveKey?: string;
    /** Called when value changes */
    onChange?(value: string): void;
    /** Name of the radio group, default to random id */
    name?: string;
    /** True if component should have 100% width */
    grow?: boolean;
    /** Active control color from theme, defaults to white in light color scheme and theme.colors.dark[9] in dark */
    color?: string | 'default' | 'primary' | 'secondary' | 'success' | 'warning' | 'error';
    /** Controls font-size, paddings and height */
    size?: KubedSizes;
    /** Border-radius from theme or number to set border-radius in px */
    radius?: KubedNumberSize;
    /** Tab controls position */
    position?: GroupPosition;
    /** Tab controls direction */
    direction?: 'horizontal' | 'vertical';
    /** Controls tab content padding-top */
    tabPadding?: KubedNumberSize;
    /** Called when tab control is clicked with tab index */
    onTabChange?(tabKey: string): void;
    /** Transition duration in ms, set to 0 to turn off transitions */
    transitionDuration?: number;
    /** Transition timing function for all transitions, defaults to theme.transitionTimingFunction */
    transitionTimingFunction?: string;
}
export declare function Tabs({ children, name, variant, activeKey, defaultActiveKey, onTabChange, color, grow, radius, size, position, direction, tabPadding, transitionDuration, transitionTimingFunction, ...others }: TabsProps): React.JSX.Element;
export declare namespace Tabs {
    var displayName: string;
}
//# sourceMappingURL=Tabs.d.ts.map